@@ -6,6 +6,7 @@ pub mod toml;
 pub struct Config {
     pub imgur: ConfigImgur,
     pub notification: ConfigNotification,
+    pub clipboard: ConfigClipboard,
 }
 
 #[derive(Debug, Deserialize)]
@@ -17,3 +18,8 @@ pub struct ConfigImgur {
 pub struct ConfigNotification {
     pub enabled: bool,
 }
+
+#[derive(Debug, Deserialize)]
+pub struct ConfigClipboard {
+    pub enabled: bool,
+}
